@@ -2,7 +2,7 @@
 Date         : 2022-12-18 12:33:46
 Author       : BDFD,bdfd2005@gmail.com
 Github       : https://github.com/bdfd
-LastEditTime : 2022-12-18 19:59:38
+LastEditTime : 2022-12-19 10:16:16
 LastEditors  : BDFD
 Description  : 
 FilePath     : \WES_Calculation\windspeed.py
@@ -717,7 +717,7 @@ def windspeed(o2, zw, Xlat, X, Rg, U, atm, Ta, zt, Tw, TaaC, wdu, zu):
     if dT==0:#20221211
         section7.extend(['滨水工',round(Up1[10],3)])
     else:
-        section7.extend(['滨水工',str(round(Up1[10],3))+'(KEYPS)',str(round(Up2[10],3))+'(B-D)'])
+        section7.extend(['滨水工',str(round(Up1[10],3))+'(KEYPS)'+'        '+str(round(Up2[10],3))+'(B-D)'])
 
     if ss1==None:
         section7.extend(['JTS 145-2015',round(Ua1,3)])
